# kraken-wrapper

[Documentation](https://kraken-build.github.io/kraken/kraken-wrapper/)

This projects implements `krakenw`, the wrapper CLI for the Kraken build system that enables reproducible builds
via lock files and executing builds from inside subdirectories.

__Installation__

You need Python 3.10 or newer:

    $ pipx install kraken-wrapper
